/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Layersummary.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Layersummary extends GenericJson {

  /**
   * The number of annotations for this layer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer annotationCount;

  /**
   * The list of annotation types contained for this layer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> annotationTypes;

  /**
   * Link to get data for this annotation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String annotationsDataLink;

  /**
   * The link to get the annotations for this layer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String annotationsLink;

  /**
   * The content version this resource is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String contentVersion;

  /**
   * The number of data items for this layer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer dataCount;

  /**
   * Unique id of this layer summary.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Resource Type
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The layer id for this summary.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String layerId;

  /**
   * URL to this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Timestamp for the last time an item in this layer was updated. (RFC 3339 UTC date-time format).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * The current version of this layer's volume annotations. Note that this version applies only to
   * the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is
   * versioned separately.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String volumeAnnotationsVersion;

  /**
   * The volume id this resource is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String volumeId;

  /**
   * The number of annotations for this layer.
   * The value returned may be {@code null}.
   */
  public Integer getAnnotationCount() {
    return annotationCount;
  }

  /**
   * The number of annotations for this layer.
   * The value set may be {@code null}.
   */
  public Layersummary setAnnotationCount(Integer annotationCount) {
    this.annotationCount = annotationCount;
    return this;
  }

  /**
   * The list of annotation types contained for this layer.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAnnotationTypes() {
    return annotationTypes;
  }

  /**
   * The list of annotation types contained for this layer.
   * The value set may be {@code null}.
   */
  public Layersummary setAnnotationTypes(java.util.List<String> annotationTypes) {
    this.annotationTypes = annotationTypes;
    return this;
  }

  /**
   * Link to get data for this annotation.
   * The value returned may be {@code null}.
   */
  public String getAnnotationsDataLink() {
    return annotationsDataLink;
  }

  /**
   * Link to get data for this annotation.
   * The value set may be {@code null}.
   */
  public Layersummary setAnnotationsDataLink(String annotationsDataLink) {
    this.annotationsDataLink = annotationsDataLink;
    return this;
  }

  /**
   * The link to get the annotations for this layer.
   * The value returned may be {@code null}.
   */
  public String getAnnotationsLink() {
    return annotationsLink;
  }

  /**
   * The link to get the annotations for this layer.
   * The value set may be {@code null}.
   */
  public Layersummary setAnnotationsLink(String annotationsLink) {
    this.annotationsLink = annotationsLink;
    return this;
  }

  /**
   * The content version this resource is for.
   * The value returned may be {@code null}.
   */
  public String getContentVersion() {
    return contentVersion;
  }

  /**
   * The content version this resource is for.
   * The value set may be {@code null}.
   */
  public Layersummary setContentVersion(String contentVersion) {
    this.contentVersion = contentVersion;
    return this;
  }

  /**
   * The number of data items for this layer.
   * The value returned may be {@code null}.
   */
  public Integer getDataCount() {
    return dataCount;
  }

  /**
   * The number of data items for this layer.
   * The value set may be {@code null}.
   */
  public Layersummary setDataCount(Integer dataCount) {
    this.dataCount = dataCount;
    return this;
  }

  /**
   * Unique id of this layer summary.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique id of this layer summary.
   * The value set may be {@code null}.
   */
  public Layersummary setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Resource Type
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource Type
   * The value set may be {@code null}.
   */
  public Layersummary setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The layer id for this summary.
   * The value returned may be {@code null}.
   */
  public String getLayerId() {
    return layerId;
  }

  /**
   * The layer id for this summary.
   * The value set may be {@code null}.
   */
  public Layersummary setLayerId(String layerId) {
    this.layerId = layerId;
    return this;
  }

  /**
   * URL to this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * URL to this resource.
   * The value set may be {@code null}.
   */
  public Layersummary setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Timestamp for the last time an item in this layer was updated. (RFC 3339 UTC date-time format).
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * Timestamp for the last time an item in this layer was updated. (RFC 3339 UTC date-time format).
   * The value set may be {@code null}.
   */
  public Layersummary setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * The current version of this layer's volume annotations. Note that this version applies only to
   * the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is
   * versioned separately.
   * The value returned may be {@code null}.
   */
  public String getVolumeAnnotationsVersion() {
    return volumeAnnotationsVersion;
  }

  /**
   * The current version of this layer's volume annotations. Note that this version applies only to
   * the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is
   * versioned separately.
   * The value set may be {@code null}.
   */
  public Layersummary setVolumeAnnotationsVersion(String volumeAnnotationsVersion) {
    this.volumeAnnotationsVersion = volumeAnnotationsVersion;
    return this;
  }

  /**
   * The volume id this resource is for.
   * The value returned may be {@code null}.
   */
  public String getVolumeId() {
    return volumeId;
  }

  /**
   * The volume id this resource is for.
   * The value set may be {@code null}.
   */
  public Layersummary setVolumeId(String volumeId) {
    this.volumeId = volumeId;
    return this;
  }

}
